@@ -46,22 +46,6 @@ typedef int status;
 #define AF_SUCCEED (0)
 #define AF_FAIL (-1)
 
-struct _codec
-{
-	AFframecount (*readFrames) (const AFfilehandle file, int track,
-		void *samples, const int count);
-	AFframecount (*writeFrames) (const AFfilehandle file, int track,
-		void *samples, const int count);
-};
-
-typedef struct _Compression
-{
-	int     type;   /* symbolic constant */
-	char    *name;  /* human-readable name */
-
-	struct _codec   *codec;
-} _Compression;
-
 typedef union AFPVu
 {
 	long	l;
@@ -255,8 +239,8 @@ typedef struct _TrackSetup
 	int		markerCount;
 	_MarkerSetup	*markers;
 
-	off_t	dataOffset;
-	off_t	frameCount;
+	AFfileoffset	dataOffset;
+	AFframecount	frameCount;
 } _TrackSetup;
 
 typedef struct _LoopSetup
@@ -359,6 +343,15 @@ enum
 	_AF_WRITE_ACCESS = 2
 };
 
+/* The following are tokens for compression parameters in PV lists. */
+enum
+{
+	_AF_SAMPLES_PER_BLOCK = 700,		/* type: long */
+	_AF_BLOCK_SIZE = 701,			/* type: long */
+	_AF_MS_ADPCM_NUM_COEFFICIENTS = 800,	/* type: long */
+	_AF_MS_ADPCM_COEFFICIENTS = 801		/* type: array of int16_t[2] */
+};
+
 /* NeXT/Sun sampling rate */
 #define _AF_SRATE_CODEC (8012.8210513)
 
